@@ -3,7 +3,7 @@ vegindex <- function(
                         index,
                         returnHCR = "auto",
                         L = 0.5,
-                        weighted = TRUE,
+                        weighted = TRUE,                        
                         ...
                     )
 
@@ -12,26 +12,27 @@ vegindex_available <- function()
 {
   av <- c("NDVI","OSAVI","SAVI","MTVI","NDWI","PWI",
           "MSI", "SRWI","GMI1","GMI2","MCARI","TVI",
-          "CI_Hanna","Vogelmann4","Boochs","Boochs2",
+          "Vogelmann4","Boochs","Boochs2",
           "CARI","CI","Carter","Carter2","Carter3","Carter4",
           "Carter5","Carter6","Datt","Datt2","Datt3","Datt4",
-          "Datt5","DDn","D1","D2","EVI","EGFR","EGFN",
+          "Datt5","Datt6","DD","DDn","D1","D2","EVI","EGFR","EGFN",
           "GI","Gitelson","Gitelson2","Green NDVI","MCARI/OSAVI",
           "MCARI2","MCARI2/OSAVI2","mNDVI","mND705","Maccioni",
           "mREIP","MSAVI","mSR","mSR705","mSR2","MTCI","NDVI2",
-          "NDVI3","NPCI","OSAVI2","RDVI","REIP","REP_LE","REP_Li",
+          "NDVI3","NPCI","OSAVI2","RDVI","REP_LE","REP_Li",
           "SIPI","SPVI","SR","SR1","SR2","SR3","SR4","SR5","SR6",
           "SR7", "SR8","SRPI","Sum_Dr1","Sum_Dr2","TCARI","TCARI2",
           "TCARI/OSAVI","TCARI2/OSAVI2","Vogelmann","NDLI",
           "Vogelmann2","Vogelmann3","PRI","CAI","NDNI",
-          "RARS", "PSSR", "PSND", "CRI1", "CRI2", "CRI3",
+          "PSSR", "PSND", "CRI1", "CRI2", "CRI3",
           "CRI4", "MPRI", "PRI*CI2", "CI2", "PSRI", "ClAInt", 
-          "GMAX", "TGI", "PRI_norm"
+          "TGI", "PRI_norm","PARS","DPI","Datt7","Datt8",
+          "GDVI_2","GDVI_3","GDVI_4","LWVI1","LWVI2",
+          "DWSI1","DWSI2","DWSI3","DWSI4","DWSI5",
+          "SWIR FI", "SWIR LI", "SWIR SI", "SWIR VI"
           )
   return(sort(av))
 }  
-  
-
 
 return_index <- function(x)
 {
@@ -49,6 +50,8 @@ if (length(names(match.call()))==0)
   return(vegindex_available())
 }
 
+x_back <- x
+
 if (!is.speclib(x))
   stop("x is not of class 'Speclib'")
 if (!x@continuousdata)
@@ -97,7 +100,7 @@ if (length(index)>1)
 }
 
 d_indexs <- c("Boochs","Boochs2","Datt3","D1","D2","EGFR","EGFN",
-              "Vogelmann3","Sum_Dr1","Sum_Dr2","REP_LE")
+              "Vogelmann3","Sum_Dr1","Sum_Dr2","REP_LE","DPI")
 m <- c(rep.int(1,length(d_indexs)))
 
 # index_current <<- index
@@ -180,10 +183,7 @@ if (index=="TVI")
   return(return_index(0.5*(120*(get_reflectance(y,x,750,weighted)-get_reflectance(y,x,550,weighted))-
                       200*(get_reflectance(y,x,670,weighted)-get_reflectance(y,x,550,weighted)))))
 }
-if (index=="CI_Hanna")
-{
-  return(return_index(get_reflectance(y,x,760,weighted)/get_reflectance(y,x,695,weighted)))
-}
+
 if (index=="Vogelmann4")
 {
   return(return_index((get_reflectance(y,x,734,weighted)-get_reflectance(y,x,747,weighted))/
@@ -260,6 +260,16 @@ if (index=="Datt6")
   return(return_index(((get_reflectance(y,x,860,weighted))/
                       (get_reflectance(y,x,550,weighted)*get_reflectance(y,x,708,weighted)))))
 }
+if (index=="Datt7")
+{
+  return(return_index((get_reflectance(y,x,860,weighted) - get_reflectance(y,x,2218,weighted))/
+                      (get_reflectance(y,x,860,weighted) - get_reflectance(y,x,1928,weighted))))
+}
+if (index=="Datt8")
+{
+  return(return_index((get_reflectance(y,x,860,weighted) - get_reflectance(y,x,1788,weighted))/
+                      (get_reflectance(y,x,860,weighted) - get_reflectance(y,x,1928,weighted))))
+}
 if (index=="DD")
 {
   return(return_index((get_reflectance(y,x,749,weighted)-get_reflectance(y,x,720,weighted))-
@@ -278,6 +288,10 @@ if (index=="D2")
 {
   return(return_index(get_reflectance(y,x,705,weighted)/get_reflectance(y,x,722,weighted)))
 }
+if (index=="DPI")
+{
+  return(return_index(get_reflectance(y,x,688,weighted)*get_reflectance(y,x,710,weighted)/get_reflectance(y,x,697,weighted)^2))
+}
 if (index=="EVI")
 {
   return(return_index(2.5*((get_reflectance(y,x,800,weighted)-get_reflectance(y,x,670,weighted))/
@@ -436,23 +450,19 @@ if (index=="RDVI")
   return(return_index((get_reflectance(y,x,800,weighted)-get_reflectance(y,x,670,weighted))/
                       (get_reflectance(y,x,800,weighted)+get_reflectance(y,x,670,weighted))^0.5))
 }
-if (index=="REIP")
-{
-  return(return_index(NULL))
-}
-if (index=="GMAX")
-{
-  if (x[1] > 400) return(NULL)
-  if (x[length(x)] < 680) return(NULL)
-  
-  mFR <- (get_reflectance(y,x,400,weighted)-get_reflectance(y,x,550,weighted))/(400-550)
-  tFR <- get_reflectance(y,x,400,weighted) - mFR * 400
-
-  mNIR <- (get_reflectance(y,x,570,weighted)-get_reflectance(y,x,680,weighted))/(570-680)
-  tNIR <- get_reflectance(y,x,570,weighted) - mNIR * 570
-  
-  return(return_index((tNIR-tFR)/(mFR-mNIR)))
-}
+# if (index=="GMAX")
+# {
+#   if (x[1] > 400) return(NULL)
+#   if (x[length(x)] < 680) return(NULL)
+#   
+#   mFR <- (get_reflectance(y,x,400,weighted)-get_reflectance(y,x,550,weighted))/(400-550)
+#   tFR <- get_reflectance(y,x,400,weighted) - mFR * 400
+# 
+#   mNIR <- (get_reflectance(y,x,570,weighted)-get_reflectance(y,x,680,weighted))/(570-680)
+#   tNIR <- get_reflectance(y,x,570,weighted) - mNIR * 570
+#   
+#   return(return_index((tNIR-tFR)/(mFR-mNIR)))
+# }
 if (index=="REP_LE")
 {
   if (x[1] > 680) return(NULL)
@@ -612,7 +622,7 @@ if (index=="NDLI")
 
 
 
-if (index=="RARS")
+if (index=="PARS")
 {
   return(return_index(get_reflectance(y,x,746,weighted)/get_reflectance(y,x,513,weighted)))
 }
@@ -685,8 +695,89 @@ if (index=="TGI")
   return(return_index(-0.5*(190*(get_reflectance(y,x,670,weighted)-get_reflectance(y,x,550,weighted)) -
                       120*(get_reflectance(y,x,670,weighted)-get_reflectance(y,x,480,weighted)))))
 }
+if (substr(index, 1, 4) == "GDVI")
+{
+  pow <- strsplit(index, "_")
+  if (length(pow[[1]]) < 2)
+  {
+    pow <- 2
+    warning("Exponent of GDVI missing. Use 2 for exponent")
+  }
+  pow <- try(as.numeric(pow[[1]][2]), silent = TRUE)
+  if (inherits(pow, "try-error"))
+  {
+    pow <- 2
+    warning("Exponent of GDVI not numeric. Use 2 for exponent")
+  }
+  return(return_index((get_reflectance(y,x,800,weighted)^pow-get_reflectance(y,x,680,weighted)^pow) /
+                      (get_reflectance(y,x,800,weighted)^pow+get_reflectance(y,x,680,weighted)^pow)))
+}
+if (index=="LWVI1")
+{
+  return(return_index((get_reflectance(y,x,1094,weighted)-get_reflectance(y,x,983,weighted)) /
+                      (get_reflectance(y,x,1094,weighted)+get_reflectance(y,x,983,weighted))))
+}
+if (index=="LWVI2")
+{
+  return(return_index((get_reflectance(y,x,1094,weighted)-get_reflectance(y,x,1205,weighted)) /
+                      (get_reflectance(y,x,1094,weighted)+get_reflectance(y,x,1205,weighted))))
+}
+if (index=="DWSI1")
+{
+  return(return_index(get_reflectance(y,x,800,weighted)/get_reflectance(y,x,1660,weighted)))
+}
+if (index=="DWSI2")
+{
+  return(return_index(get_reflectance(y,x,1660,weighted)/get_reflectance(y,x,550,weighted)))
+}
+if (index=="DWSI3")
+{
+  return(return_index(get_reflectance(y,x,1660,weighted)/get_reflectance(y,x,680,weighted)))
+}
+if (index=="DWSI4")
+{
+  return(return_index(get_reflectance(y,x,550,weighted)/get_reflectance(y,x,680,weighted)))
+}
+if (index=="DWSI5")
+{
+  return(return_index((get_reflectance(y,x,800,weighted)+get_reflectance(y,x,550,weighted)) /
+                      (get_reflectance(y,x,1660,weighted)+get_reflectance(y,x,680,weighted))))
+}
+if (index=="SWIR FI")
+{
+  return(return_index((get_reflectance(y,x,2133,weighted)^2) /
+                      (get_reflectance(y,x,2225,weighted)*get_reflectance(y,x,2209,weighted)^3)))
+}
+if (index=="SWIR LI")
+{
+  return(return_index(3.87* (get_reflectance(y,x,2210,weighted)-get_reflectance(y,x,2090,weighted)) -
+	              27.51*(get_reflectance(y,x,2280,weighted)-get_reflectance(y,x,2090,weighted)) - 0.2))
+}
+if (index=="SWIR SI")
+{
+  return(return_index(-41.59* (get_reflectance(y,x,2210,weighted)-get_reflectance(y,x,2090,weighted)) +
+	              1.24*(get_reflectance(y,x,2280,weighted)-get_reflectance(y,x,2090,weighted)) + 0.64))
+}
+if (index=="SWIR VI")
+{
+  return(return_index(37.72* (get_reflectance(y,x,2210,weighted)-get_reflectance(y,x,2090,weighted)) +
+	              26.27*(get_reflectance(y,x,2280,weighted)-get_reflectance(y,x,2090,weighted)) + 0.57))
+}
 
 
-return(NULL)
-
+index <- gsub("R", "", gsub("(R[0-9]+)", "get_reflectance(y,x,\\1,weighted)", index, 
+                            perl = TRUE)
+              )
+index <- gsub("D", "", gsub("(D[0-9]+)", "get_reflectance(spectra(derivative.speclib(x_back, m=1, ...)),x,\\1,weighted)", index, 
+                            perl = TRUE)
+              )
+index_val <- try(return_index(eval(parse(text = index))), silent = TRUE)
+if (inherits(index_val, "try-error"))
+{
+  cat("Error in self-defined index string or unimplemented index selected\n")
+  cat("Index string evals to:\n")
+  cat(paste(index, "\n"))
+  return(NULL)
+}  
+return(index_val)
 }
